@@ -3,16 +3,14 @@ from logging import getLogger
 
 from beartype import beartype
 
-from cript.nodes import (
-    Base,
-    Group,
-    Experiment,
-    Ingredient,
-    Material,
-    Property,
-    Condition,
-    Citation,
-)
+from cript.nodes.primary.base_primary import BasePrimary
+from cript.nodes.primary.group import Group
+from cript.nodes.primary.experiment import Experiment
+from cript.nodes.primary.material import Material
+from cript.nodes.secondary.ingredient import Ingredient
+from cript.nodes.secondary.property import Property
+from cript.nodes.secondary.condition import Condition
+from cript.nodes.secondary.citation import Citation
 from cript.validators import validate_required, validate_key
 from cript.utils import auto_assign_group
 
@@ -20,13 +18,12 @@ from cript.utils import auto_assign_group
 logger = getLogger(__name__)
 
 
-class Process(Base):
+class Process(BasePrimary):
     """
     Object representing a process of creating or transforming
     a :class:`Material` object.
     """
 
-    node_type = "primary"
     node_name = "Process"
     slug = "process"
     list_name = "processes"
@@ -42,7 +39,7 @@ class Process(Base):
         type: str = None,
         keywords: Union[list[str], None] = None,
         description: Union[str, None] = None,
-        prerequisite_processes: list[Union[Base, str]] = None,
+        prerequisite_processes: list[Union[BasePrimary, str]] = None,
         ingredients: list[Union[Ingredient, dict]] = None,
         equipment: list[Union[str, None]] = None,
         properties: list[Union[Property, dict]] = None,
@@ -53,9 +50,7 @@ class Process(Base):
         notes: Union[str, None] = None,
         public: bool = False,
     ):
-        super().__init__()
-        self.url = None
-        self.uid = None
+        super().__init__(public=public)
         self.group = auto_assign_group(group, experiment)
         self.experiment = experiment
         self.name = name
@@ -73,9 +68,6 @@ class Process(Base):
         self.products = products if products else []
         self.citations = citations if citations else []
         self.notes = notes
-        self.public = public
-        self.created_at = None
-        self.updated_at = None
         validate_required(self)
 
     @property
@@ -109,11 +101,11 @@ class Process(Base):
         self._equipment = value
 
     @beartype
-    def add_prerequisite_process(self, process: Union[Base, dict]):
+    def add_prerequisite_process(self, process: Union[BasePrimary, dict]):
         self._add_node(process, "prerequisite_processes")
 
     @beartype
-    def remove_prerequisite_process(self, process: Union[Base, int]):
+    def remove_prerequisite_process(self, process: Union[BasePrimary, int]):
         self._remove_node(process, "prerequisite_processes")
 
     @beartype
