@@ -25,7 +25,7 @@ def validate_key(key_category, key):
     """
     Validates that the key name is in the controlled vocabulary.
 
-    :key_category: Name of the relevant key category.
+    :param key_category: Name of the relevant key category.
     :param key: Name of the key.
     :return: The validated key name.
     :rtype: str
@@ -43,7 +43,7 @@ def validate_value(key_category, key, value, unit=None):
     """
     Validates a value is within the defined parameters.
 
-    :key_category: Name of the relevant key category.
+    :param key_category: Name of the relevant key category.
     :param key: Name of the key.
     :param value: Value to be validated.
     :param unit: The value's unit of measurement.
@@ -116,30 +116,32 @@ def _validate_value_range(key, value, value_range, unit, si_unit):
     :param unit: The unit entered by the user.
     :param si_unit: The SI unit for the specific attribute.
     """
-    min, max = value_range[0], value_range[1]
+    min_, max_ = value_range[0], value_range[1]
 
     # convert to SI units if defined
     if si_unit:
-        value = _unit_conversion(value, unit, si_unit)
+        pint_unit = _validate_unit(key, unit, si_unit)
+        pint_quantity = value * pint_unit
+        value = pint_quantity.to(si_unit).magnitude
 
-    if not min <= value <= max:
-        raise InvalidValueRangeError(key, value, min, max, si_unit)
+    if not min_ <= value <= max_:
+        raise InvalidValueRangeError(key, value, min_, max_, si_unit)
 
 
 def validate_unit(key_category, key, unit):
     """
     Validates that the unit exists and can be converted to SI units.
 
-    :key_category: Name of the relevant key category.
+    :param key_category: Name of the relevant key category.
     :param key: Name of the key.
     :param unit: Unit to be validated.
     :return: The validated unit.
     :rtype: str
     """
-    _validate_unit_exists(unit)
-
     # Skip further validation for custom fields
     if not key or key[0] == "+":
+        if unit:
+            _validate_pint_unit(unit)
         return unit
 
     key_parameters = _get_key_parameters(key_category, key)
@@ -153,26 +155,12 @@ def validate_unit(key_category, key, unit):
     elif unit and not si_unit:
         raise RequiredUnitError(f"A unit is not permitted for {key}.")
 
-    _validate_unit_exists(unit)
-
-    _validate_unit_conversion(key, unit, si_unit)
+    _validate_unit(key, unit, si_unit)
 
     return unit
 
 
-def _validate_unit_exists(unit):
-    """
-    Validates that the unit exists.
-
-    :param unit: The unit entered by the user.
-    """
-    try:
-        pint_ureg[unit]
-    except:
-        raise InvalidUnitError(f"{unit} is not a recognized unit of measure.")
-
-
-def _validate_unit_conversion(key, unit, si_unit):
+def _validate_unit(key, unit, si_unit) -> pint_ureg.Unit:
     """
     Validates that the unit can be converted to appropriate SI units.
 
@@ -180,35 +168,36 @@ def _validate_unit_conversion(key, unit, si_unit):
     :param unit: The unit entered by the user.
     :param si_unit: The SI unit for the specific attribute.
     """
-    try:
-        _unit_conversion(1, unit, si_unit)
-    except:
+    pint_unit = _validate_pint_unit(unit)
+
+    if pint_unit.dimensionality != pint_ureg.Unit(si_unit).dimensionality:
         raise InvalidUnitError(f"{unit} is not a recognized unit of measure for {key}.")
 
+    return pint_unit
 
-def _unit_conversion(value, unit, si_unit):
+
+def _validate_pint_unit(unit) -> pint_ureg.Unit:
     """
-    Converts a value to SI units.
+    Validates that the unit can be converted to appropriate SI units.
 
-    :param value: The value entered by the user.
     :param unit: The unit entered by the user.
-    :param si_unit: The SI unit for the specific attribute.
-    :return: The converted value.
-    :rtype: Union[int, float, str]
     """
-    original_quantity = pint_ureg.Quantity(value, unit)
-    si_value = original_quantity.to(si_unit).magnitude
-    return si_value
+    try:
+        pint_unit = pint_ureg.Unit(unit)
+    except Exception as e:
+        raise InvalidUnitError(f"{unit} is not a recognized unit of measure.")
+
+    return pint_unit
 
 
 def _get_key_parameters(key_category, key):
     """
     Get the parameters for a given key from full keys dictionary.
 
-    :key_category: Name of the relevant key category.
+    :param key_category: Name of the relevant key category.
     :param key: Name of the key.
     """
-    from cript.session import API
+    from cript.api import API
 
     if API.keys:
         # Fetch relevant keys
